## Old Steam Assets

This is a guide on how to find old art for Steam games!

### Recommended Software

The Wayback Machine browser extension from Internet Archive to assist in making and retrieving asset archives.
- [Chrome](https://chromewebstore.google.com/detail/wayback-machine/fpnmgdkabkmnadcjpehmlllkndpkmiak?hl=en-US), [Edge](https://microsoftedge.microsoft.com/addons/detail/wayback-machine/kjmickeoogghaimmomagaghnogelpcpn?hl=en-US), [Firefox](https://addons.mozilla.org/en-US/firefox/addon/wayback-machine_new/)

The SteamDB browser extension to add buttons on Steam pages to take you their corresponding SteamDB entries.
- [Chrome](https://chromewebstore.google.com/detail/steamdb/kdbmhfkmnlmbkgbabkdealhhbfhlmmon?utm_source=SteamDB), [Edge](https://microsoftedge.microsoft.com/addons/detail/steamdb/hjknpdomhlodgaebegjopkmfafjpbblg?utm_source=SteamDB), [Firefox](https://addons.mozilla.org/en-US/firefox/addon/steam-database/?utm_source=SteamDB)

### Finding Current Assets

You can find the current Steam assets for a game by navigating to its entry on [SteamGridDB](https://www.steamgriddb.com/), or on [SteamDB](https://steamdb.info/).
- On SteamGridDB, click on the "View Original Steam Assets" button to view the current assets.
- On SteamDB, click on the "App info" tab, then scroll down to the "Assets" section.

Now you have direct access to the current Steam assets. An asset URL should look something like: `https://<domain>/steam/apps/<app id>/<asset>?t=<timestamp>`

### Archiving Assets

Once you have found a direct link to a Steam asset, you can create an archive of it with the Wayback Machine.

- Using the Wayback Machine extension, right click on the direct link to the asset, then select *Wayback Machine* > *Save Page Now*. 
- Or if you are already viewing the image directly, right click on the page away from the image, then select *Wayback Machine* > *Save Page Now*.
	- Alternatively, you can open the extension from your browser toolbar, then select *Save Page Now*.

### Browsing Archives

- If you'd like to view past versions of an asset, start by right-clicking on its direct link, then select *Wayback Machine* > *All Versions*.
- Or if you are already viewing the image directly, right click on the page away from the image, then select *Wayback Machine* > *All Versions*. 

You will be taken to the Wayback Machine's archive browser for the URL you have entered. This archive page URL should look like: `https://web.archive.org/web/<date>*/<asset URL>`

At this point, you will need to edit the archive URL to maximize your search. Delete the `date` portion of the URL after `web.archive.org/web/` leaving only an asterisk `*`. Then at the end of the asset URL, delete the `?t=<timestamp>` portion, leaving only an asterisk `*` at the end. 

This modified URL should look like: `https://web.archive.org/web/*/https://<domain>/steam/apps/<app id>/<asset>*`

If you proceed to that address, you will be able to see a list of all archived URLs on *that domain* containing a version of that asset. If no captures have been made, try replacing the domain of your URL with another from the bottom of this guide to check if the asset may have been archived from a different domain.

Once you have found one or more archived URLs, you can choose one to view captures of that specific URL. 

### Cross-Referencing Updates

Pay attention to the dates of archives, as they correspond to the specific versions of a given asset. You can cross-reference these dates with historical information on SteamDB to determine exactly when an asset was replaced with a new version. 

To view this data, you will need to sign in to SteamDB with your Steam account. Then go to the SteamDB entry for a game and navigate to the "Update history" tab. Press the "Load filters" button, then select the filter corresponding to the asset you are trying to research.

Library Assets
- `common_library_assets` - library asset addition/removal
- `website_assets` - library/store asset updates
- `common_store_asset_mtime` - library/store asset update timestamps

Store Assets
- Small Capsule -> `common_small_capsule`

Community Assets
- Client Icon -> `common_clienticon`, `common_clienttga`
- Community Icon -> `common_icon`
- Small Capsule -> `common_logo`, `common_logo_small`

When used correctly, you should be able to clearly see exactly when an asset was added, and each time it was modified in the update history. Using these dates, you can create a list of all the versions of an asset, and more effectively guide your search for historical assets.

### Posting to SteamGridDB

You can post any old Steam assets you come across to SGDB, provided that they do not match the current Steam assets. You can also document when the asset was archived or even when it was first used on Steam by using the notes field on your submission.

In order to reduce the storage burden on SGDB, current Steam assets are not allowed to be posted to SGDB. However, if you'd like to ensure that the current assets are preserved anyway, make an archive with the Wayback Machine!

### Steam Asset Types

Steam has a wide range of asset types used across its services. SteamGridDB accepts a **select number** of these asset types relevant to game libraries.

- [Library Assets](https://partner.steamgames.com/doc/store/assets/libraryassets): `https://<domain>/steam/apps/<app id>/<asset>`
	1. **Library Capsule** 
		- **600 x 900 px** `library_600x900_2x.jpg` (introduced late 2019)
		- 300 x 450 px `library_600x900.jpg` (introduced late 2019)
	2. **Library Header** 
		- **920 x 430 px** `library_header_2x.jpg` (introduced late 2024)
		- **460 x 215 px** `library_header.jpg`
    3. **Library Hero** 
		- **3840 x 1240 px** `library_hero_2x.jpg`
		- **1920 x 620 px** `library_hero.jpg`
    4. **Library Logo** 
		- **1280 x 720 px**  `logo_2x.png`
		- **640 x 720 px** `logo.png`
- [Store Assets](https://partner.steamgames.com/doc/store/assets/standard): `https://<domain>/steam/apps/<app id>/<asset>`
	1. **Header Capsule** 
		- **920 x 430 px** `header_2x.jpg` (introduced late 2024)
		- **460 x 215 px** `header.jpg`, `header_<language>.jpg`, `header_alt_assets_<#>.jpg`
		- 292 x 136 px `header_292x136.jpg`, `header_292x136_alt_assets_<#>.jpg`
    2. Small Capsule 
		- 462 x 174 px `capsule_231x87_2x.jpg` (introduced late 2024)
		- 231 x 87 px `capsule_231x87.jpg`, `capsule_231x87_<language>.jpg`, `capsule_231x87_alt_assets_<#>.jpg`
	3. Large Capsule
		- 467 x 181 px `capsule_467x181.jpg` (deprecated late 2019)
    4. Main Capsule 
		- 1232 x 706 px `capsule_616x353_2x.jpg` (introduced late 2024)
		- 616 x 353 px `capsule_616x353.jpg`, `capsule_616x353_alt_assets_0.jpg`
    5. Vertical Capsule
		- 748 x 896 px `hero_capsule_2x.jpg` (introduced late 2024)
		- 374 x 448 px `hero_capsule.jpg`
    6. Screenshots 
		- 1920 x 1080 px `ss_<hexadecimal hash>.1920x1080.jpg`
		- 1280 x 720 px `ss_<hexadecimal hash>.1280x720.jpg`
    7. Page Background 
		- 1438 x 810 px `page_bg_raw.jpg`
    8. Bundle Assets 
		- 707 x 232 px `header.jpg`
		- 586 x 192 px `header_586x192.jpg`
		- **460 x 215 px** `header_ratio.jpg`
- [Community Assets](https://partner.steamgames.com/doc/store/assets/community): `https://<domain>/steamcommunity/public/images/apps/<app id>/<asset>`
	1. **Client Icon**
		- **32 x 32 px** `<hexadecimal hash>.ico`
		- 16 x 16 px `<hexadecimal hash>.tga`
	2. Community Icon
		- 184 x 184 px `<hexadecimal hash>.jpg`
		- 32 x 32 px (deprecated)
	3. Community Capsule (Small Capsule)
		- 184 x 69 px `<hexadecimal hash>.jpg`
		- 120 x 45 px `<hexadecimal hash>_thumb.jpg`
- [Event Assets](https://partner.steamgames.com/doc/store/assets/eventassets) `https://<domain>/images/<number>/<asset>`
	1. Cover Image
		- 800 x 450 px `<hexadecimal hash>.png`
		- 400 x 225 px `<hexadecimal hash>_400x255.png`
	2. Header Image
		- 1920 x 622 px `<hexadecimal hash>.png`
		- 960 x 311 px `<hexadecimal hash>_960x311.png`

### Asset Domains

These are the websites where Steam assets are hosted from.

Library & Store Assets
- `shared.akamai.steamstatic.com/store_item_assets`
- `shared.cloudflare.steamstatic.com/store_item_assets`
- `cdn.akamai.steamstatic.com`
- `cdn.cloudflare.steamstatic.com`

Community Assets
- `cdn.akamai.steamstatic.com`
- `cdn.cloudflare.steamstatic.com`

Event Assets
- `clan.akamai.steamstatic.com`
- `clan.cloudflare.steamstatic.com`

Old Domain
- `steamcdn-a.akamaihd.net`
